@@ -1,10 +1,9 @@
 import unittest
-import collections
-
-from mock import patch, Mock
 
+from unittest.mock import patch, Mock
 import pyeapi.utils
 
+from collections.abc import Iterable
 
 class TestUtils(unittest.TestCase):
 
@@ -23,19 +22,20 @@ class TestUtils(unittest.TestCase):
 
     def test_make_iterable_from_string(self):
         result = pyeapi.utils.make_iterable('test')
-        self.assertIsInstance(result, collections.Iterable)
+        self.assertIsInstance(result, Iterable)
         self.assertEqual(len(result), 1)
 
     def test_make_iterable_from_unicode(self):
         result = pyeapi.utils.make_iterable(u'test')
-        self.assertIsInstance(result, collections.Iterable)
+        self.assertIsInstance(result, Iterable)
         self.assertEqual(len(result), 1)
 
     def test_make_iterable_from_iterable(self):
         result = pyeapi.utils.make_iterable(['test'])
-        self.assertIsInstance(result, collections.Iterable)
+        self.assertIsInstance(result, Iterable)
         self.assertEqual(len(result), 1)
 
+
     def test_make_iterable_raises_type_error(self):
         with self.assertRaises(TypeError):
             pyeapi.utils.make_iterable(object())
